==> haskell-unixutils-1.54.2-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Unixutils
version:              1.54.2
visibility:           public
id:                   Unixutils-1.54.2-2kfpTQhaIJdg3jESMJLg1
key:                  Unixutils-1.54.2-2kfpTQhaIJdg3jESMJLg1
license:              BSD-3-Clause
maintainer:           jeremy@n-heptane.com
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  b1b14866c3f5c4e888df95b8220273de
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-9.0.2/site-local/Unixutils-1.54.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/Unixutils-1.54.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unixutils
hs-libraries:         HSUnixutils-1.54.2-2kfpTQhaIJdg3jESMJLg1
extra-libraries:      crypt
depends:
    base-4.15.1.0 bytestring-0.10.12.1 directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.1 mtl-2.2.2 process-1.6.13.2
    process-extras-0.7.4-J0vtJWzJlaKDsbDOFvI5oG
    pureMD5-2.1.4-3agKXHxhmvV8zJpppmb9ox
    regex-tdfa-1.3.1.3-LXeydEuwMNICkheie0vWXl unix-2.7.2.2
    zlib-0.6.3.0-7sRFbB6f3ZDFUPAe6PoyXI

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unixutils-1.54.2-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Unixutils
version:              1.54.2
visibility:           public
id:                   Unixutils-1.54.2-2lOOidey42HBwxfbBJ069U
key:                  Unixutils-1.54.2-2lOOidey42HBwxfbBJ069U
license:              BSD-3-Clause
maintainer:           jeremy@n-heptane.com
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  6eefc4140834472f78163c29181f474e
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-9.0.2/site-local/Unixutils-1.54.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/Unixutils-1.54.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unixutils
hs-libraries:         HSUnixutils-1.54.2-2lOOidey42HBwxfbBJ069U
extra-libraries:      crypt
depends:
    base-4.15.1.0 bytestring-0.10.12.1 directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.1 mtl-2.2.2 process-1.6.13.2
    process-extras-0.7.4-BAPdySIpPdS1SCSrqv88uf
    pureMD5-2.1.4-3agKXHxhmvV8zJpppmb9ox
    regex-tdfa-1.3.1.4-Cm6vevfL5SU5WGhLB3p1sr unix-2.7.2.2
    zlib-0.6.3.0-3f0KnZYdRdU1LSRzbCkBW

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
